package renderer

import (
	"net/http"

	diagsstorage "git.coopgo.io/coopgo-platform/diags/storage"
)

const diagsMenu = "diags"

func (renderer *Renderer) DiagsHome(w http.ResponseWriter, r *http.Request, diags []diagsstorage.Diag) {
	files := renderer.ThemeConfig.GetStringSlice("views.diags.list.files")
	state := NewState(r, renderer.ThemeConfig, diagsMenu)
	state.ViewState = map[string]any{
		"diags": diags,
	}

	renderer.Render("diags home", w, r, files, state)
}

func (renderer *Renderer) DiagsHistory(w http.ResponseWriter, r *http.Request, diags []diagsstorage.Diag) {
	files := renderer.ThemeConfig.GetStringSlice("views.diags.history.files")
	state := NewState(r, renderer.ThemeConfig, diagsMenu)
	state.ViewState = map[string]any{
		"diags": diags,
	}

	renderer.Render("diags history", w, r, files, state)
}

func (renderer *Renderer) BeneficiariesCreateDiag(w http.ResponseWriter, r *http.Request, beneficiary string, diags_file_types []string, file_types_map map[string]string, documents any) {
	state := NewState(r, renderer.ThemeConfig, diagsMenu)
	files := renderer.ThemeConfig.GetStringSlice("views.beneficiaries.create_diag.files")
	state.ViewState = map[string]any{
		"beneficiary": beneficiary,
		"diags_file_types": diags_file_types,
		"file_types_map": file_types_map,
		"documents": documents,
	}
	renderer.Render("diag create for beneficiary", w, r, files, state)
}

func (renderer *Renderer) VehiclesCreateDiag(w http.ResponseWriter, r *http.Request, vehicle string) {
	state := NewState(r, renderer.ThemeConfig, diagsMenu)
	files := renderer.ThemeConfig.GetStringSlice("views.vehicles_management.create_vehicle_diag.files")
	state.ViewState = map[string]any{
		"vehicle": vehicle,
	}
	renderer.Render("diag create for vehicle", w, r, files, state)
}

func (renderer *Renderer) BookingsCreateDiag(w http.ResponseWriter, r *http.Request, booking string) {
	state := NewState(r, renderer.ThemeConfig, diagsMenu)
	files := renderer.ThemeConfig.GetStringSlice("views.vehicles_management.create_booking_diag.files")
	state.ViewState = map[string]any{
		"booking": booking,
	}
	renderer.Render("diag create for booking", w, r, files, state)
}

func (renderer *Renderer) VehicleBookingsCreateDiag(w http.ResponseWriter, r *http.Request, booking string) {
	state := NewState(r, renderer.ThemeConfig, diagsMenu)
	files := renderer.ThemeConfig.GetStringSlice("views.vehicles.create_booking_diag.files")
	state.ViewState = map[string]any{
		"booking": booking,
	}
	renderer.Render("diag create for booking", w, r, files, state)
}

func (renderer *Renderer) DiagsDisplayDiag(w http.ResponseWriter, r *http.Request, diag any, diags_file_types []string, file_types_map map[string]string, documents any) {
	files := renderer.ThemeConfig.GetStringSlice("views.diags.display_diag.files")
	state := NewState(r, renderer.ThemeConfig, diagsMenu)

	state.ViewState = map[string]any{
		"diag":         	 diag,
		"diags_file_types": diags_file_types,
		"file_types_map":	 file_types_map,
		"documents":     	 documents,
	}

	renderer.Render("diags create diag", w, r, files, state)
}

func (renderer *Renderer) DiagsHistoryDiag(w http.ResponseWriter, r *http.Request, diag any) {
	files := renderer.ThemeConfig.GetStringSlice("views.diags.history_diag.files")
	state := NewState(r, renderer.ThemeConfig, diagsMenu)
	state.ViewState = map[string]any{
		"diag":         diag,
	}

	renderer.Render("diags history diag", w, r, files, state)
}

func (renderer *Renderer) DiagUpdate(w http.ResponseWriter, r *http.Request, diag any) {
	files := renderer.ThemeConfig.GetStringSlice("views.diags.update.files")
	state := NewState(r, renderer.ThemeConfig, diagsMenu)

	state.ViewState = map[string]any{
		"diag": diag,
	}

	renderer.Render("diag_update", w, r, files, state)
}

func (renderer *Renderer) DiagDelete(w http.ResponseWriter, r *http.Request, diag any) {
	files := renderer.ThemeConfig.GetStringSlice("views.diags.delete.files")
	state := NewState(r, renderer.ThemeConfig, diagsMenu)

	state.ViewState = map[string]any{
		"diag": diag,
	}

	renderer.Render("diag_deleteDiag", w, r, files, state)
}